@@ -6,8 +6,6 @@ our(@ISA, %EXPORT_TAGS, @EXPORT_OK, @EXPORT, $AUTOLOAD, %SIGRT) = ();
 
 our $VERSION = "1.13";
 
-use AutoLoader;
-
 use XSLoader ();
 
 use Fcntl qw(FD_CLOEXEC F_DUPFD F_GETFD F_GETFL F_GETLK F_RDLCK F_SETFD
@@ -41,8 +39,7 @@ sub AUTOLOAD {
     no warnings 'uninitialized';
     if ($AUTOLOAD =~ /::(_?[a-z])/) {
 	# require AutoLoader;
-	$AutoLoader::AUTOLOAD = $AUTOLOAD;
-	goto &AutoLoader::AUTOLOAD
+        croak "subroutine $AUTOLOAD does not exist";
     }
     local $! = 0;
     my $constname = $AUTOLOAD;
@@ -50,24 +47,18 @@ sub AUTOLOAD {
     if ($NON_CONSTS{$constname}) {
         my ($val, $error) = &int_macro_int($constname, $_[0]);
         croak $error if $error;
-        *$AUTOLOAD = sub { &int_macro_int($constname, $_[0]) };
+        *{Symbol::fetch_glob($AUTOLOAD)} = sub { &int_macro_int($constname, $_[0]) };
     } else {
         my ($error, $val) = constant($constname);
         croak $error if $error;
-	*$AUTOLOAD = sub { $val };
+	*{Symbol::fetch_glob($AUTOLOAD)} = sub { $val };
     }
 
-    goto &$AUTOLOAD;
+    goto &{Symbol::fetch_glob($AUTOLOAD)};
 }
 
-package POSIX::SigAction;
-
-use AutoLoader 'AUTOLOAD';
-
 package POSIX::SigRt;
 
-use AutoLoader 'AUTOLOAD';
-
 use Tie::Hash;
 
 use vars qw($SIGACTION_FLAGS $_SIGRTMIN $_SIGRTMAX $_sigrtn @ISA);
@@ -81,9 +72,6 @@ sub DESTROY {};
 
 package POSIX;
 
-1;
-__END__
-
 sub usage {
     my ($mess) = @_;
     croak "Usage: POSIX::$mess";
@@ -590,7 +578,7 @@ sub fstat {
     usage "fstat(fd)" if @_ != 1;
     local *TMP;
     CORE::open(TMP, "<&$_[0]");		# Gross.
-    my @l = CORE::stat(TMP);
+    my @l = CORE::stat(*TMP);
     CORE::close(TMP);
     @l;
 }
@@ -763,8 +751,6 @@ sub utime {
     CORE::utime($_[1], $_[2], $_[0]);
 }
 
-our (%EXPORT_TAGS, @EXPORT_OK, @EXPORT);
-
 sub load_imports {
 %EXPORT_TAGS = (
 
