@@ -2457,315 +2457,6 @@ Perl_hv_placeholders_set(pTHX_ HV *hv, I32 ph)
     /* else we don't need to add magic to record 0 placeholders.  */
 }
 
-STATIC SV *
-S_refcounted_he_value(pTHX_ const struct refcounted_he *he)
-{
-    dVAR;
-    SV *value;
-    switch(he->refcounted_he_data[0] & HVrhek_typemask) {
-    case HVrhek_undef:
-	value = newSV(0);
-	break;
-    case HVrhek_delete:
-	value = &PL_sv_placeholder;
-	break;
-    case HVrhek_IV:
-	value = newSViv(he->refcounted_he_val.refcounted_he_u_iv);
-	break;
-    case HVrhek_UV:
-	value = newSVuv(he->refcounted_he_val.refcounted_he_u_uv);
-	break;
-    case HVrhek_PV:
-	/* Create a string SV that directly points to the bytes in our
-	   structure.  */
-	value = newSV_type(SVt_PV);
-	SvPV_set(value, (char *) he->refcounted_he_data + 1);
-	SvCUR_set(value, he->refcounted_he_val.refcounted_he_u_len);
-	/* This stops anything trying to free it  */
-	SvLEN_set(value, 0);
-	SvPOK_on(value);
-	SvREADONLY_on(value);
-	break;
-    default:
-	Perl_croak(aTHX_ "panic: refcounted_he_value bad flags %x",
-		   he->refcounted_he_data[0]);
-    }
-    return value;
-}
-
-/*
-=for apidoc refcounted_he_chain_2hv
-
-Generates and returns a C<HV *> by walking up the tree starting at the passed
-in C<struct refcounted_he *>.
-
-=cut
-*/
-HV *
-Perl_refcounted_he_chain_2hv(pTHX_ const struct refcounted_he *chain)
-{
-    dVAR;
-    HV *hv = newHV();
-    U32 placeholders = 0;
-    /* We could chase the chain once to get an idea of the number of keys,
-       and call ksplit.  But for now we'll make a potentially inefficient
-       hash with only 8 entries in its array.  */
-    const U32 max = HvMAX(hv);
-
-    if (!HvARRAY(hv)) {
-	char *array;
-	Newxz(array, PERL_HV_ARRAY_ALLOC_BYTES(max + 1), char);
-	HvARRAY(hv) = (HE**)array;
-    }
-
-    while (chain) {
-#ifdef USE_ITHREADS
-	U32 hash = chain->refcounted_he_hash;
-#else
-	U32 hash = HEK_HASH(chain->refcounted_he_hek);
-#endif
-	HE **oentry = &((HvARRAY(hv))[hash & max]);
-	HE *entry = *oentry;
-	SV *value;
-
-	for (; entry; entry = HeNEXT(entry)) {
-	    if (HeHASH(entry) == hash) {
-		/* We might have a duplicate key here.  If so, entry is older
-		   than the key we've already put in the hash, so if they are
-		   the same, skip adding entry.  */
-#ifdef USE_ITHREADS
-		const STRLEN klen = HeKLEN(entry);
-		const char *const key = HeKEY(entry);
-		if (klen == chain->refcounted_he_keylen
-		    && (!!HeKUTF8(entry)
-			== !!(chain->refcounted_he_data[0] & HVhek_UTF8))
-		    && memEQ(key, REF_HE_KEY(chain), klen))
-		    goto next_please;
-#else
-		if (HeKEY_hek(entry) == chain->refcounted_he_hek)
-		    goto next_please;
-		if (HeKLEN(entry) == HEK_LEN(chain->refcounted_he_hek)
-		    && memEQ(HeKEY(entry), HEK_KEY(chain->refcounted_he_hek),
-			     HeKLEN(entry)))
-		    goto next_please;
-#endif
-	    }
-	}
-	assert (!entry);
-	entry = new_HE();
-
-#ifdef USE_ITHREADS
-	HeKEY_hek(entry)
-	    = share_hek_flags(REF_HE_KEY(chain),
-			      chain->refcounted_he_keylen,
-			      chain->refcounted_he_hash,
-			      0);
-#else
-	HeKEY_hek(entry) = share_hek_hek(chain->refcounted_he_hek);
-#endif
-	value = refcounted_he_value(chain);
-	if (value == &PL_sv_placeholder)
-	    placeholders++;
-	HeVAL(entry) = value;
-
-	/* Link it into the chain.  */
-	HeNEXT(entry) = *oentry;
-	if (!HeNEXT(entry)) {
-	    /* initial entry.   */
-	    HvFILL(hv)++;
-	}
-	*oentry = entry;
-
-	HvTOTALKEYS(hv)++;
-
-    next_please:
-	chain = chain->refcounted_he_next;
-    }
-
-    if (placeholders) {
-	clear_placeholders(hv, placeholders);
-	HvTOTALKEYS(hv) -= placeholders;
-    }
-
-    DEBUG_A(Perl_hv_assert(aTHX_ hv));
-
-    return hv;
-}
-
-SV *
-Perl_refcounted_he_fetch(pTHX_ const struct refcounted_he *chain, SV *keysv,
-			 const char *key, STRLEN klen, int flags, U32 hash)
-{
-    dVAR;
-    /* Just to be awkward, if you're using this interface the UTF-8-or-not-ness
-       of your key has to exactly match that which is stored.  */
-    SV *value = &PL_sv_placeholder;
-
-    if (keysv) {
-	if (flags & HVhek_FREEKEY)
-	    Safefree(key);
-	key = SvPV_const(keysv, klen);
-	flags = 0;
-    }
-
-    if (!hash) {
-	if (keysv && (SvIsCOW_shared_hash(keysv))) {
-            hash = SvSHARED_HASH(keysv);
-        } else {
-            PERL_HASH(hash, key, klen);
-        }
-    }
-
-    for (; chain; chain = chain->refcounted_he_next) {
-#ifdef USE_ITHREADS
-	if (hash != chain->refcounted_he_hash)
-	    continue;
-	if (klen != chain->refcounted_he_keylen)
-	    continue;
-	if (memNE(REF_HE_KEY(chain),key,klen))
-	    continue;
-#else
-	if (hash != HEK_HASH(chain->refcounted_he_hek))
-	    continue;
-	if (klen != (STRLEN)HEK_LEN(chain->refcounted_he_hek))
-	    continue;
-	if (memNE(HEK_KEY(chain->refcounted_he_hek),key,klen))
-	    continue;
-#endif
-
-	value = sv_2mortal(refcounted_he_value(chain));
-	break;
-    }
-
-    if (flags & HVhek_FREEKEY)
-	Safefree(key);
-
-    return value;
-}
-
-/*
-=for apidoc refcounted_he_new
-
-Creates a new C<struct refcounted_he>. As S<key> is copied, and value is
-stored in a compact form, all references remain the property of the caller.
-The C<struct refcounted_he> is returned with a reference count of 1.
-
-=cut
-*/
-
-struct refcounted_he *
-Perl_refcounted_he_new(pTHX_ struct refcounted_he *const parent,
-		       SV *const key, SV *const value) {
-    dVAR;
-    struct refcounted_he *he;
-    STRLEN key_len;
-    const char *key_p = SvPV_const(key, key_len);
-    STRLEN value_len = 0;
-    const char *value_p = NULL;
-    char value_type;
-    char flags;
-    STRLEN key_offset;
-    U32 hash;
-
-    if (SvPOK(value)) {
-	value_type = HVrhek_PV;
-    } else if (SvIOK(value)) {
-	value_type = HVrhek_IV;
-    } else if (value == &PL_sv_placeholder) {
-	value_type = HVrhek_delete;
-    } else if (!SvOK(value)) {
-	value_type = HVrhek_undef;
-    } else {
-	value_type = HVrhek_PV;
-    }
-
-    if (value_type == HVrhek_PV) {
-	value_p = SvPV_const(value, value_len);
-	key_offset = value_len + 2;
-    } else {
-	value_len = 0;
-	key_offset = 1;
-    }
-
-#ifdef USE_ITHREADS
-    he = (struct refcounted_he*)
-	PerlMemShared_malloc(sizeof(struct refcounted_he) - 1
-			     + key_len
-			     + key_offset);
-#else
-    he = (struct refcounted_he*)
-	PerlMemShared_malloc(sizeof(struct refcounted_he) - 1
-			     + key_offset);
-#endif
-
-
-    he->refcounted_he_next = parent;
-
-    if (value_type == HVrhek_PV) {
-	Copy(value_p, he->refcounted_he_data + 1, value_len + 1, char);
-	he->refcounted_he_val.refcounted_he_u_len = value_len;
-    } else if (value_type == HVrhek_IV) {
-	if (SvUOK(value)) {
-	    he->refcounted_he_val.refcounted_he_u_uv = SvUVX(value);
-	    value_type = HVrhek_UV;
-	} else {
-	    he->refcounted_he_val.refcounted_he_u_iv = SvIVX(value);
-	}
-    }
-    flags = value_type;
-
-    PERL_HASH(hash, key_p, key_len);
-
-#ifdef USE_ITHREADS
-    he->refcounted_he_hash = hash;
-    he->refcounted_he_keylen = key_len;
-    Copy(key_p, he->refcounted_he_data + key_offset, key_len, char);
-#else
-    he->refcounted_he_hek = share_hek_flags(key_p, key_len, hash, flags);
-#endif
-
-    he->refcounted_he_data[0] = flags;
-    he->refcounted_he_refcnt = 1;
-
-    return he;
-}
-
-/*
-=for apidoc refcounted_he_free
-
-Decrements the reference count of the passed in C<struct refcounted_he *>
-by one. If the reference count reaches zero the structure's memory is freed,
-and C<refcounted_he_free> iterates onto the parent node.
-
-=cut
-*/
-
-void
-Perl_refcounted_he_free(pTHX_ struct refcounted_he *he) {
-    dVAR;
-    PERL_UNUSED_CONTEXT;
-
-    while (he) {
-	struct refcounted_he *copy;
-	U32 new_count;
-
-	HINTS_REFCNT_LOCK;
-	new_count = --he->refcounted_he_refcnt;
-	HINTS_REFCNT_UNLOCK;
-	
-	if (new_count) {
-	    return;
-	}
-
-#ifndef USE_ITHREADS
-	unshare_hek_or_pvn (he->refcounted_he_hek, 0, 0, 0);
-#endif
-	copy = he;
-	he = he->refcounted_he_next;
-	PerlMemShared_free(copy);
-    }
-}
-
 /*
 =for apidoc hv_assert
 
