@@ -197,8 +197,8 @@ sub ret_backtrace {
   $i++;
 
   my $tid_msg = '';
-  if (defined &Thread::tid) {
-    my $tid = Thread->self->tid;
+  if (defined &threads::tid) {
+    my $tid = threads->tid;
     $tid_msg = " thread $tid" if $tid;
   }
 
@@ -218,8 +218,8 @@ sub ret_summary {
   $i++;
 
   my $tid_msg = '';
-  if (defined &Thread::tid) {
-    my $tid = Thread->self->tid;
+  if (defined &threads::tid) {
+    my $tid = threads->tid;
     $tid_msg = " thread $tid" if $tid;
   }
 
@@ -302,9 +302,9 @@ sub trusts_directly {
     my $class = shift;
     no strict 'refs';
     no warnings 'once'; 
-    return @{"$class\::CARP_NOT"}
-      ? @{"$class\::CARP_NOT"}
-      : @{"$class\::ISA"};
+    return @{*{Symbol::fetch_glob("$class\::CARP_NOT")}}
+      ? @{*{Symbol::fetch_glob("$class\::CARP_NOT")}}
+      : @{*{Symbol::fetch_glob("$class\::ISA")}};
 }
 
 1;
