@@ -1395,7 +1395,7 @@ sub _accessorize {  # A simple-minded method-maker
   no strict 'refs';
   foreach my $attrname (@_) {
     next if $attrname =~ m/::/; # a hack
-    *{caller() . '::' . $attrname} = sub {
+    *{Symbol::fetch_glob(caller() . '::' . $attrname)} = sub {
       use strict;
       $Carp::CarpLevel = 1,  Carp::croak(
        "Accessor usage: \$obj->$attrname() or \$obj->$attrname(\$new_value)"
